@@ -7,6 +7,9 @@ use MIME::Base64;
 
 use base qw( OAuth::Cmdline );
 
+our $VERSION = '0.07'; # VERSION
+# ABSTRACT: Automatic.com-specific OAuth oddities
+
 ###########################################
 sub site {
 ###########################################
@@ -25,10 +28,18 @@ sub redirect_uri {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 OAuth::Cmdline::Automatic - Automatic.com-specific OAuth oddities
 
+=head1 VERSION
+
+version 0.07
+
 =head1 SYNOPSIS
 
     my $oauth = OAuth::Cmdline::Automatic->new( );
@@ -111,12 +122,15 @@ data from the server:
           $device->{ url };
     }
 
-=head1 LEGALESE
-
-Copyright 2016 by Mike Schilli, all rights reserved.
-This program is free software, you can redistribute it and/or
-modify it under the same terms as Perl itself.
-
 =head1 AUTHOR
 
-2016, Mike Schilli <cpan@perlmeister.com>
+Mike Schilli <cpan@perlmeister.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2022 by Mike Schilli.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
