@@ -7,6 +7,9 @@ use MIME::Base64;
 
 use base qw( OAuth::Cmdline );
 
+our $VERSION = '0.07'; # VERSION
+# ABSTRACT: Spotify-specific OAuth oddities
+
 ###########################################
 sub site {
 ###########################################
@@ -33,10 +36,18 @@ sub token_refresh_authorization_header {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 OAuth::Cmdline::Spotify - Spotify-specific OAuth oddities
 
+=head1 VERSION
+
+version 0.07
+
 =head1 SYNOPSIS
 
     my $oauth = OAuth::Cmdline::Spotify->new( );
@@ -47,12 +58,15 @@ OAuth::Cmdline::Spotify - Spotify-specific OAuth oddities
 This class overrides methods of C<OAuth::Cmdline> to comply with
 Spotify's Web API.
 
-=head1 LEGALESE
-
-Copyright 2014 by Mike Schilli, all rights reserved.
-This program is free software, you can redistribute it and/or
-modify it under the same terms as Perl itself.
-
 =head1 AUTHOR
 
-2014, Mike Schilli <cpan@perlmeister.com>
+Mike Schilli <cpan@perlmeister.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2022 by Mike Schilli.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
