@@ -6,6 +6,9 @@ use warnings;
 use MIME::Base64;
 use base qw( OAuth::Cmdline );
 
+our $VERSION = '0.07'; # VERSION
+# ABSTRACT: Youtube-specific settings for OAuth::Cmdline
+
 ###########################################
 sub site {
 ###########################################
@@ -16,10 +19,18 @@ sub site {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 OAuth::Cmdline::Youtube - Youtube-specific settings for OAuth::Cmdline
 
+=head1 VERSION
+
+version 0.07
+
 =head1 SYNOPSIS
 
     my $oauth = OAuth::Cmdline::Youtube->new( );
@@ -30,12 +41,15 @@ OAuth::Cmdline::Youtube - Youtube-specific settings for OAuth::Cmdline
 This class overrides methods of C<OAuth::Cmdline> if Youtube's Web API 
 requires it.
 
-=head1 LEGALESE
-
-Copyright 2016 by Mike Schilli, all rights reserved.
-This program is free software, you can redistribute it and/or
-modify it under the same terms as Perl itself.
-
 =head1 AUTHOR
 
-2016, Mike Schilli <cpan@perlmeister.com>
+Mike Schilli <cpan@perlmeister.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2022 by Mike Schilli.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
